@@ -53,6 +53,7 @@ var _ = Describe("LogForwarding", func() {
 						Name: "instance",
 					},
 					Spec: logforward.ForwardingSpec{
+						DisableDefaultForwarding: true,
 						Outputs: []logforward.OutputSpec{
 							logforward.OutputSpec{
 								Name:     fluentDeployment.ObjectMeta.Name,
@@ -126,6 +127,7 @@ var _ = Describe("LogForwarding", func() {
 						Name: "instance",
 					},
 					Spec: logforward.ForwardingSpec{
+						DisableDefaultForwarding: true,
 						Outputs: []logforward.OutputSpec{
 							logforward.OutputSpec{
 								Name:     fluentDeployment.ObjectMeta.Name,
@@ -176,6 +178,7 @@ var _ = Describe("LogForwarding", func() {
 
 		AfterEach(func() {
 			e2e.Cleanup()
+			e2e.WaitForCleanupCompletion([]string{"fluent-receiver", "fluentd"})
 		})
 
 	})
